summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2010-05-06 14:27:04 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2010-05-06 14:27:04 (GMT)
commit5b320d81abb8c228f2ded592b1d725a8c668ba37 (patch)
treeab6ee31765740cd0e521183959bf97debb0a1e09 /src
parent810f4373e340364b8862e807422262a34bac037b (diff)
downloadhdf5-5b320d81abb8c228f2ded592b1d725a8c668ba37.zip
hdf5-5b320d81abb8c228f2ded592b1d725a8c668ba37.tar.gz
hdf5-5b320d81abb8c228f2ded592b1d725a8c668ba37.tar.bz2
[svn-r18724] Description:
Rename H5[A]C_rename to H5[A]C_move_entry. Tested on: Mac OS X/32 10.6.3 (amazon) w/debug & production (h5committest not required on this branch)
Diffstat (limited to 'src')
-rw-r--r--src/H5AC.c101
-rw-r--r--src/H5ACpkg.h18
-rw-r--r--src/H5ACprivate.h4
-rw-r--r--src/H5B.c2
-rw-r--r--src/H5C.c118
-rw-r--r--src/H5Cpkg.h56
-rw-r--r--src/H5Cprivate.h4
-rw-r--r--src/H5Edefin.h4
-rw-r--r--src/H5Einit.h12
-rw-r--r--src/H5Epubgen.h6
-rw-r--r--src/H5Eterm.h292
-rw-r--r--src/H5FSsection.c8
-rw-r--r--src/H5HFcache.c8
-rw-r--r--src/H5HFiblock.c6
-rw-r--r--src/H5HL.c4
-rw-r--r--src/H5err.txt4
16 files changed, 297 insertions, 350 deletions
diff --git a/src/H5ACprivate.h b/src/H5ACprivate.h
index 4d210ac..06f199b 100644
--- a/src/H5ACprivate.h
+++ b/src/H5ACprivate.h
@@ -117,7 +117,7 @@ typedef enum {
#define H5AC_CALLBACK__NO_FLAGS_SET H5C_CALLBACK__NO_FLAGS_SET
#define H5AC_CALLBACK__SIZE_CHANGED_FLAG H5C_CALLBACK__SIZE_CHANGED_FLAG
-#define H5AC_CALLBACK__RENAMED_FLAG H5C_CALLBACK__RENAMED_FLAG
+#define H5AC_CALLBACK__MOVED_FLAG H5C_CALLBACK__MOVED_FLAG
typedef H5C_load_func_t H5AC_load_func_t;
typedef H5C_flush_func_t H5AC_flush_func_t;
@@ -278,7 +278,7 @@ H5_DLL herr_t H5AC_unprotect(H5F_t *f, hid_t dxpl_id,
void *thing, unsigned flags);
H5_DLL herr_t H5AC_flush(H5F_t *f, hid_t dxpl_id, unsigned flags);
H5_DLL herr_t H5AC_mark_entry_dirty(void *thing);
-H5_DLL herr_t H5AC_rename(H5F_t *f, const H5AC_class_t *type,
+H5_DLL herr_t H5AC_move_entry(H5F_t *f, const H5AC_class_t *type,
haddr_t old_addr, haddr_t new_addr);
H5_DLL herr_t H5AC_dest(H5F_t *f, hid_t dxpl_id);
diff --git a/src/H5B.c b/src/H5B.c
index 5b9f733..f7ede07 100644
--- a/src/H5B.c
+++ b/src/H5B.c
@@ -693,7 +693,7 @@ H5B_insert(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, haddr_t addr,
bt = NULL; /* Make certain future references will be caught */
/* Move the location of the old root on the disk */
- if(H5AC_rename(f, H5AC_BT, addr, old_root) < 0)
+ if(H5AC_move_entry(f, H5AC_BT, addr, old_root) < 0)
HGOTO_ERROR(H5E_BTREE, H5E_CANTSPLIT, FAIL, "unable to move B-tree root node")
/* clear the old root info at the old address (we already copied it) */
diff --git a/src/H5Cprivate.h b/src/H5Cprivate.h
index 768a4f0..8418a09 100644
--- a/src/H5Cprivate.h
+++ b/src/H5Cprivate.h
@@ -119,7 +119,7 @@ typedef struct H5C_t H5C_t;
#define H5C_CALLBACK__NO_FLAGS_SET 0x0
#define H5C_CALLBACK__SIZE_CHANGED_FLAG 0x1
-#define H5C_CALLBACK__RENAMED_FLAG 0x2
+#define H5C_CALLBACK__MOVED_FLAG 0x2
typedef void *(*H5C_load_func_t)(H5F_t *f,
hid_t dxpl_id,
@@ -1038,7 +1038,7 @@ H5_DLL herr_t H5C_mark_entries_as_clean(H5F_t * f,
H5_DLL herr_t H5C_mark_entry_dirty(void *thing);
-H5_DLL herr_t H5C_rename_entry(H5C_t * cache_ptr,
+H5_DLL herr_t H5C_move_entry(H5C_t * cache_ptr,
const H5C_class_t * type,
haddr_t old_addr,
haddr_t new_addr);
diff --git a/src/H5Edefin.h b/src/H5Edefin.h
index 5638305..9ca9371 100644
--- a/src/H5Edefin.h
+++ b/src/H5Edefin.h
@@ -106,6 +106,7 @@ hid_t H5E_CANTDELETE_g = FAIL; /* Can't delete message */
hid_t H5E_BADITER_g = FAIL; /* Iteration failed */
hid_t H5E_CANTPACK_g = FAIL; /* Can't pack messages */
hid_t H5E_CANTRESET_g = FAIL; /* Can't reset object */
+hid_t H5E_CANTRENAME_g = FAIL; /* Unable to rename object */
/* System level errors */
hid_t H5E_SYSERRSTR_g = FAIL; /* System error message */
@@ -154,7 +155,6 @@ hid_t H5E_PROTECT_g = FAIL; /* Protected metadata error */
hid_t H5E_NOTCACHED_g = FAIL; /* Metadata not currently cached */
hid_t H5E_SYSTEM_g = FAIL; /* Internal error detected */
hid_t H5E_CANTINS_g = FAIL; /* Unable to insert metadata into cache */
-hid_t H5E_CANTRENAME_g = FAIL; /* Unable to rename metadata */
hid_t H5E_CANTPROTECT_g = FAIL; /* Unable to protect metadata */
hid_t H5E_CANTUNPROTECT_g = FAIL; /* Unable to unprotect metadata */
hid_t H5E_CANTPIN_g = FAIL; /* Unable to pin cache entry */
@@ -168,7 +168,7 @@ hid_t H5E_CANTRESIZE_g = FAIL; /* Unable to resize a metadata cache ent
hid_t H5E_TRAVERSE_g = FAIL; /* Link traversal failure */
hid_t H5E_NLINKS_g = FAIL; /* Too many soft links in path */
hid_t H5E_NOTREGISTERED_g = FAIL; /* Link class not registered */
-hid_t H5E_CANTMOVE_g = FAIL; /* Move callback returned error */
+hid_t H5E_CANTMOVE_g = FAIL; /* Can't move object */
hid_t H5E_CANTSORT_g = FAIL; /* Can't sort objects */
/* Parallel MPI errors */
diff --git a/src/H5Einit.h b/src/H5Einit.h
index ac02d48..977fadd 100644
--- a/src/H5Einit.h
+++ b/src/H5Einit.h
@@ -388,6 +388,11 @@ if((msg = H5E_create_msg(cls, H5E_MINOR, "Can't reset object"))==NULL)
HGOTO_ERROR(H5E_ERROR, H5E_CANTINIT, FAIL, "error message initialization failed")
if((H5E_CANTRESET_g = H5I_register(H5I_ERROR_MSG, msg))<0)
HGOTO_ERROR(H5E_ERROR, H5E_CANTREGISTER, FAIL, "can't register error message")
+assert(H5E_CANTRENAME_g==(-1));
+if((msg = H5E_create_msg(cls, H5E_MINOR, "Unable to rename object"))==NULL)
+ HGOTO_ERROR(H5E_ERROR, H5E_CANTINIT, FAIL, "error message initialization failed")
+if((H5E_CANTRENAME_g = H5I_register(H5I_ERROR_MSG, msg))<0)
+ HGOTO_ERROR(H5E_ERROR, H5E_CANTREGISTER, FAIL, "can't register error message")
/* System level errors */
assert(H5E_SYSERRSTR_g==(-1));
@@ -572,11 +577,6 @@ if((msg = H5E_create_msg(cls, H5E_MINOR, "Unable to insert metadata into cache")
HGOTO_ERROR(H5E_ERROR, H5E_CANTINIT, FAIL, "error message initialization failed")
if((H5E_CANTINS_g = H5I_register(H5I_ERROR_MSG, msg))<0)
HGOTO_ERROR(H5E_ERROR, H5E_CANTREGISTER, FAIL, "can't register error message")
-assert(H5E_CANTRENAME_g==(-1));
-if((msg = H5E_create_msg(cls, H5E_MINOR, "Unable to rename metadata"))==NULL)
- HGOTO_ERROR(H5E_ERROR, H5E_CANTINIT, FAIL, "error message initialization failed")
-if((H5E_CANTRENAME_g = H5I_register(H5I_ERROR_MSG, msg))<0)
- HGOTO_ERROR(H5E_ERROR, H5E_CANTREGISTER, FAIL, "can't register error message")
assert(H5E_CANTPROTECT_g==(-1));
if((msg = H5E_create_msg(cls, H5E_MINOR, "Unable to protect metadata"))==NULL)
HGOTO_ERROR(H5E_ERROR, H5E_CANTINIT, FAIL, "error message initialization failed")
@@ -635,7 +635,7 @@ if((msg = H5E_create_msg(cls, H5E_MINOR, "Link class not registered"))==NULL)
if((H5E_NOTREGISTERED_g = H5I_register(H5I_ERROR_MSG, msg))<0)
HGOTO_ERROR(H5E_ERROR, H5E_CANTREGISTER, FAIL, "can't register error message")
assert(H5E_CANTMOVE_g==(-1));
-if((msg = H5E_create_msg(cls, H5E_MINOR, "Move callback returned error"))==NULL)
+if((msg = H5E_create_msg(cls, H5E_MINOR, "Can't move object"))==NULL)
HGOTO_ERROR(H5E_ERROR, H5E_CANTINIT, FAIL, "error message initialization failed")
if((H5E_CANTMOVE_g = H5I_register(H5I_ERROR_MSG, msg))<0)
HGOTO_ERROR(H5E_ERROR, H5E_CANTREGISTER, FAIL, "can't register error message")
diff --git a/src/H5Epubgen.h b/src/H5Epubgen.h
index 8386e0f..68fd177 100644
--- a/src/H5Epubgen.h
+++ b/src/H5Epubgen.h
@@ -172,6 +172,7 @@ H5_DLLVAR hid_t H5E_CANTSHRINK_g; /* Can't shrink container */
#define H5E_BADITER (H5OPEN H5E_BADITER_g)
#define H5E_CANTPACK (H5OPEN H5E_CANTPACK_g)
#define H5E_CANTRESET (H5OPEN H5E_CANTRESET_g)
+#define H5E_CANTRENAME (H5OPEN H5E_CANTRENAME_g)
H5_DLLVAR hid_t H5E_LINKCOUNT_g; /* Bad object header link count */
H5_DLLVAR hid_t H5E_VERSION_g; /* Wrong version number */
H5_DLLVAR hid_t H5E_ALIGNMENT_g; /* Alignment error */
@@ -180,6 +181,7 @@ H5_DLLVAR hid_t H5E_CANTDELETE_g; /* Can't delete message */
H5_DLLVAR hid_t H5E_BADITER_g; /* Iteration failed */
H5_DLLVAR hid_t H5E_CANTPACK_g; /* Can't pack messages */
H5_DLLVAR hid_t H5E_CANTRESET_g; /* Can't reset object */
+H5_DLLVAR hid_t H5E_CANTRENAME_g; /* Unable to rename object */
/* System level errors */
#define H5E_SYSERRSTR (H5OPEN H5E_SYSERRSTR_g)
@@ -255,7 +257,6 @@ H5_DLLVAR hid_t H5E_NOIDS_g; /* Out of IDs for group */
#define H5E_NOTCACHED (H5OPEN H5E_NOTCACHED_g)
#define H5E_SYSTEM (H5OPEN H5E_SYSTEM_g)
#define H5E_CANTINS (H5OPEN H5E_CANTINS_g)
-#define H5E_CANTRENAME (H5OPEN H5E_CANTRENAME_g)
#define H5E_CANTPROTECT (H5OPEN H5E_CANTPROTECT_g)
#define H5E_CANTUNPROTECT (H5OPEN H5E_CANTUNPROTECT_g)
#define H5E_CANTPIN (H5OPEN H5E_CANTPIN_g)
@@ -271,7 +272,6 @@ H5_DLLVAR hid_t H5E_PROTECT_g; /* Protected metadata error */
H5_DLLVAR hid_t H5E_NOTCACHED_g; /* Metadata not currently cached */
H5_DLLVAR hid_t H5E_SYSTEM_g; /* Internal error detected */
H5_DLLVAR hid_t H5E_CANTINS_g; /* Unable to insert metadata into cache */
-H5_DLLVAR hid_t H5E_CANTRENAME_g; /* Unable to rename metadata */
H5_DLLVAR hid_t H5E_CANTPROTECT_g; /* Unable to protect metadata */
H5_DLLVAR hid_t H5E_CANTUNPROTECT_g; /* Unable to unprotect metadata */
H5_DLLVAR hid_t H5E_CANTPIN_g; /* Unable to pin cache entry */
@@ -290,7 +290,7 @@ H5_DLLVAR hid_t H5E_CANTRESIZE_g; /* Unable to resize a metadata cache entry
H5_DLLVAR hid_t H5E_TRAVERSE_g; /* Link traversal failure */
H5_DLLVAR hid_t H5E_NLINKS_g; /* Too many soft links in path */
H5_DLLVAR hid_t H5E_NOTREGISTERED_g; /* Link class not registered */
-H5_DLLVAR hid_t H5E_CANTMOVE_g; /* Move callback returned error */
+H5_DLLVAR hid_t H5E_CANTMOVE_g; /* Can't move object */
H5_DLLVAR hid_t H5E_CANTSORT_g; /* Can't sort objects */
/* Parallel MPI errors */
diff --git a/src/H5Eterm.h b/src/H5Eterm.h
index 57be03d..85eb19e 100644
--- a/src/H5Eterm.h
+++ b/src/H5Eterm.h
@@ -21,193 +21,193 @@
#define _H5Eterm_H
/* Reset major error IDs */
-
-H5E_DATASET_g=
-H5E_FUNC_g=
-H5E_STORAGE_g=
-H5E_FILE_g=
-H5E_SOHM_g=
-H5E_SYM_g=
-H5E_VFL_g=
-H5E_INTERNAL_g=
-H5E_BTREE_g=
-H5E_REFERENCE_g=
-H5E_DATASPACE_g=
-H5E_RESOURCE_g=
-H5E_PLIST_g=
-H5E_LINK_g=
-H5E_DATATYPE_g=
-H5E_RS_g=
-H5E_HEAP_g=
-H5E_OHDR_g=
-H5E_ATOM_g=
-H5E_ATTR_g=
-H5E_NONE_MAJOR_g=
-H5E_IO_g=
-H5E_SLIST_g=
-H5E_EFL_g=
-H5E_TST_g=
-H5E_ARGS_g=
-H5E_ERROR_g=
-H5E_PLINE_g=
-H5E_FSPACE_g=
+
+H5E_DATASET_g=
+H5E_FUNC_g=
+H5E_STORAGE_g=
+H5E_FILE_g=
+H5E_SOHM_g=
+H5E_SYM_g=
+H5E_VFL_g=
+H5E_INTERNAL_g=
+H5E_BTREE_g=
+H5E_REFERENCE_g=
+H5E_DATASPACE_g=
+H5E_RESOURCE_g=
+H5E_PLIST_g=
+H5E_LINK_g=
+H5E_DATATYPE_g=
+H5E_RS_g=
+H5E_HEAP_g=
+H5E_OHDR_g=
+H5E_ATOM_g=
+H5E_ATTR_g=
+H5E_NONE_MAJOR_g=
+H5E_IO_g=
+H5E_SLIST_g=
+H5E_EFL_g=
+H5E_TST_g=
+H5E_ARGS_g=
+H5E_ERROR_g=
+H5E_PLINE_g=
+H5E_FSPACE_g=
H5E_CACHE_g= (-1);
/* Reset minor error IDs */
-/* Generic low-level file I/O errors */
-H5E_SEEKERROR_g=
-H5E_READERROR_g=
-H5E_WRITEERROR_g=
-H5E_CLOSEERROR_g=
-H5E_OVERFLOW_g=
+/* Generic low-level file I/O errors */
+H5E_SEEKERROR_g=
+H5E_READERROR_g=
+H5E_WRITEERROR_g=
+H5E_CLOSEERROR_g=
+H5E_OVERFLOW_g=
H5E_FCNTL_g=
-/* Resource errors */
-H5E_NOSPACE_g=
-H5E_CANTALLOC_g=
-H5E_CANTCOPY_g=
-H5E_CANTFREE_g=
-H5E_ALREADYEXISTS_g=
-H5E_CANTLOCK_g=
-H5E_CANTUNLOCK_g=
-H5E_CANTGC_g=
-H5E_CANTGETSIZE_g=
+/* Resource errors */
+H5E_NOSPACE_g=
+H5E_CANTALLOC_g=
+H5E_CANTCOPY_g=
+H5E_CANTFREE_g=
+H5E_ALREADYEXISTS_g=
+H5E_CANTLOCK_g=
+H5E_CANTUNLOCK_g=
+H5E_CANTGC_g=
+H5E_CANTGETSIZE_g=
H5E_OBJOPEN_g=
-/* Heap errors */
-H5E_CANTRESTORE_g=
-H5E_CANTCOMPUTE_g=
-H5E_CANTEXTEND_g=
-H5E_CANTATTACH_g=
-H5E_CANTUPDATE_g=
+/* Heap errors */
+H5E_CANTRESTORE_g=
+H5E_CANTCOMPUTE_g=
+H5E_CANTEXTEND_g=
+H5E_CANTATTACH_g=
+H5E_CANTUPDATE_g=
H5E_CANTOPERATE_g=
-/* Function entry/exit interface errors */
-H5E_CANTINIT_g=
-H5E_ALREADYINIT_g=
+/* Function entry/exit interface errors */
+H5E_CANTINIT_g=
+H5E_ALREADYINIT_g=
H5E_CANTRELEASE_g=
-/* Property list errors */
-H5E_CANTGET_g=
-H5E_CANTSET_g=
+/* Property list errors */
+H5E_CANTGET_g=
+H5E_CANTSET_g=
H5E_DUPCLASS_g=
-/* Free space errors */
-H5E_CANTMERGE_g=
-H5E_CANTREVIVE_g=
+/* Free space errors */
+H5E_CANTMERGE_g=
+H5E_CANTREVIVE_g=
H5E_CANTSHRINK_g=
-/* Object header related errors */
-H5E_LINKCOUNT_g=
-H5E_VERSION_g=
-H5E_ALIGNMENT_g=
-H5E_BADMESG_g=
-H5E_CANTDELETE_g=
-H5E_BADITER_g=
-H5E_CANTPACK_g=
-H5E_CANTRESET_g=
-
-/* System level errors */
+/* Object header related errors */
+H5E_LINKCOUNT_g=
+H5E_VERSION_g=
+H5E_ALIGNMENT_g=
+H5E_BADMESG_g=
+H5E_CANTDELETE_g=
+H5E_BADITER_g=
+H5E_CANTPACK_g=
+H5E_CANTRESET_g=
+H5E_CANTRENAME_g=
+
+/* System level errors */
H5E_SYSERRSTR_g=
-/* I/O pipeline errors */
-H5E_NOFILTER_g=
-H5E_CALLBACK_g=
-H5E_CANAPPLY_g=
-H5E_SETLOCAL_g=
-H5E_NOENCODER_g=
+/* I/O pipeline errors */
+H5E_NOFILTER_g=
+H5E_CALLBACK_g=
+H5E_CANAPPLY_g=
+H5E_SETLOCAL_g=
+H5E_NOENCODER_g=
H5E_CANTFILTER_g=
-/* Group related errors */
-H5E_CANTOPENOBJ_g=
-H5E_CANTCLOSEOBJ_g=
-H5E_COMPLEN_g=
+/* Group related errors */
+H5E_CANTOPENOBJ_g=
+H5E_CANTCLOSEOBJ_g=
+H5E_COMPLEN_g=
H5E_PATH_g=
-/* No error */
+/* No error */
H5E_NONE_MINOR_g=
-/* File accessability errors */
-H5E_FILEEXISTS_g=
-H5E_FILEOPEN_g=
-H5E_CANTCREATE_g=
-H5E_CANTOPENFILE_g=
-H5E_CANTCLOSEFILE_g=
-H5E_NOTHDF5_g=
-H5E_BADFILE_g=
-H5E_TRUNCATED_g=
+/* File accessability errors */
+H5E_FILEEXISTS_g=
+H5E_FILEOPEN_g=
+H5E_CANTCREATE_g=
+H5E_CANTOPENFILE_g=
+H5E_CANTCLOSEFILE_g=
+H5E_NOTHDF5_g=
+H5E_BADFILE_g=
+H5E_TRUNCATED_g=
H5E_MOUNT_g=
-/* Object atom related errors */
-H5E_BADATOM_g=
-H5E_BADGROUP_g=
-H5E_CANTREGISTER_g=
-H5E_CANTINC_g=
-H5E_CANTDEC_g=
+/* Object atom related errors */
+H5E_BADATOM_g=
+H5E_BADGROUP_g=
+H5E_CANTREGISTER_g=
+H5E_CANTINC_g=
+H5E_CANTDEC_g=
H5E_NOIDS_g=
-/* Cache related errors */
-H5E_CANTFLUSH_g=
-H5E_CANTSERIALIZE_g=
-H5E_CANTLOAD_g=
-H5E_PROTECT_g=
-H5E_NOTCACHED_g=
-H5E_SYSTEM_g=
-H5E_CANTINS_g=
-H5E_CANTRENAME_g=
-H5E_CANTPROTECT_g=
-H5E_CANTUNPROTECT_g=
-H5E_CANTPIN_g=
-H5E_CANTUNPIN_g=
-H5E_CANTMARKDIRTY_g=
-H5E_CANTDIRTY_g=
-H5E_CANTEXPUNGE_g=
+/* Cache related errors */
+H5E_CANTFLUSH_g=
+H5E_CANTSERIALIZE_g=
+H5E_CANTLOAD_g=
+H5E_PROTECT_g=
+H5E_NOTCACHED_g=
+H5E_SYSTEM_g=
+H5E_CANTINS_g=
+H5E_CANTPROTECT_g=
+H5E_CANTUNPROTECT_g=
+H5E_CANTPIN_g=
+H5E_CANTUNPIN_g=
+H5E_CANTMARKDIRTY_g=
+H5E_CANTDIRTY_g=
+H5E_CANTEXPUNGE_g=
H5E_CANTRESIZE_g=
-/* Link related errors */
-H5E_TRAVERSE_g=
-H5E_NLINKS_g=
-H5E_NOTREGISTERED_g=
-H5E_CANTMOVE_g=
+/* Link related errors */
+H5E_TRAVERSE_g=
+H5E_NLINKS_g=
+H5E_NOTREGISTERED_g=
+H5E_CANTMOVE_g=
H5E_CANTSORT_g=
-/* Parallel MPI errors */
-H5E_MPI_g=
-H5E_MPIERRSTR_g=
+/* Parallel MPI errors */
+H5E_MPI_g=
+H5E_MPIERRSTR_g=
H5E_CANTRECV_g=
-/* Dataspace errors */
-H5E_CANTCLIP_g=
-H5E_CANTCOUNT_g=
-H5E_CANTSELECT_g=
-H5E_CANTNEXT_g=
-H5E_BADSELECT_g=
+/* Dataspace errors */
+H5E_CANTCLIP_g=
+H5E_CANTCOUNT_g=
+H5E_CANTSELECT_g=
+H5E_CANTNEXT_g=
+H5E_BADSELECT_g=
H5E_CANTCOMPARE_g=
-/* Argument errors */
-H5E_UNINITIALIZED_g=
-H5E_UNSUPPORTED_g=
-H5E_BADTYPE_g=
-H5E_BADRANGE_g=
+/* Argument errors */
+H5E_UNINITIALIZED_g=
+H5E_UNSUPPORTED_g=
+H5E_BADTYPE_g=
+H5E_BADRANGE_g=
H5E_BADVALUE_g=
-/* B-tree related errors */
-H5E_NOTFOUND_g=
-H5E_EXISTS_g=
-H5E_CANTENCODE_g=
-H5E_CANTDECODE_g=
-H5E_CANTSPLIT_g=
-H5E_CANTREDISTRIBUTE_g=
-H5E_CANTSWAP_g=
-H5E_CANTINSERT_g=
-H5E_CANTLIST_g=
-H5E_CANTMODIFY_g=
+/* B-tree related errors */
+H5E_NOTFOUND_g=
+H5E_EXISTS_g=
+H5E_CANTENCODE_g=
+H5E_CANTDECODE_g=
+H5E_CANTSPLIT_g=
+H5E_CANTREDISTRIBUTE_g=
+H5E_CANTSWAP_g=
+H5E_CANTINSERT_g=
+H5E_CANTLIST_g=
+H5E_CANTMODIFY_g=
H5E_CANTREMOVE_g=
-/* Datatype conversion errors */
-H5E_CANTCONVERT_g=
+/* Datatype conversion errors */
+H5E_CANTCONVERT_g=
H5E_BADSIZE_g= (-1);
#endif /* H5Eterm_H */
diff --git a/src/H5FSsection.c b/src/H5FSsection.c
index b107829..32ef5b6 100644
--- a/src/H5FSsection.c
+++ b/src/H5FSsection.c
@@ -1377,8 +1377,8 @@ HDfprintf(stderr, "%s: old_addr = %a, fspace->sect_addr = %a\n", FUNC, old_addr,
/* Move object in cache, if it actually was relocated */
if(H5F_addr_ne(fspace->sect_addr, old_addr)) {
- if(H5AC_rename(f, H5AC_FSPACE_SINFO, old_addr, fspace->sect_addr) < 0)
- HGOTO_ERROR(H5E_FSPACE, H5E_CANTRENAME, FAIL, "unable to move free space section info")
+ if(H5AC_move_entry(f, H5AC_FSPACE_SINFO, old_addr, fspace->sect_addr) < 0)
+ HGOTO_ERROR(H5E_FSPACE, H5E_CANTMOVE, FAIL, "unable to move free space section info")
} /* end if */
else {
/* Mark free space section as dirty */
@@ -1442,8 +1442,8 @@ HDfprintf(stderr, "%s: Allocating space for smaller serialized sections, new_siz
/* Move object in cache, if it actually was relocated */
if(H5F_addr_ne(fspace->sect_addr, old_addr)) {
- if(H5AC_rename(f, H5AC_FSPACE_SINFO, old_addr, fspace->sect_addr) < 0)
- HGOTO_ERROR(H5E_FSPACE, H5E_CANTRENAME, FAIL, "unable to move free space section info")
+ if(H5AC_move_entry(f, H5AC_FSPACE_SINFO, old_addr, fspace->sect_addr) < 0)
+ HGOTO_ERROR(H5E_FSPACE, H5E_CANTMOVE, FAIL, "unable to move free space section info")
} /* end if */
else {
/* Mark free space section as dirty */
diff --git a/src/H5HFcache.c b/src/H5HFcache.c
index dc5d234..31b3d55 100644
--- a/src/H5HFcache.c
+++ b/src/H5HFcache.c
@@ -1418,8 +1418,8 @@ H5HF_cache_dblock_flush(H5F_t *f, hid_t dxpl_id, hbool_t destroy, haddr_t addr,
/* Let the metadata cache know, if the block moved */
if(!H5F_addr_eq(hdr->man_dtable.table_addr, addr))
- if(H5AC_rename(f, H5AC_FHEAP_DBLOCK, hdr->man_dtable.table_addr, addr) < 0)
- HGOTO_ERROR(H5E_HEAP, H5E_CANTRENAME, FAIL, "unable to move direct block")
+ if(H5AC_move_entry(f, H5AC_FHEAP_DBLOCK, hdr->man_dtable.table_addr, addr) < 0)
+ HGOTO_ERROR(H5E_HEAP, H5E_CANTMOVE, FAIL, "unable to move direct block")
/* Update information about compressed direct block's location & size */
hdr->man_dtable.table_addr = addr;
@@ -1465,8 +1465,8 @@ H5HF_cache_dblock_flush(H5F_t *f, hid_t dxpl_id, hbool_t destroy, haddr_t addr,
/* Let the metadata cache know, if the block moved */
if(!H5F_addr_eq(par_iblock->ents[par_entry].addr, addr))
- if(H5AC_rename(f, H5AC_FHEAP_DBLOCK, par_iblock->ents[par_entry].addr, addr) < 0)
- HGOTO_ERROR(H5E_HEAP, H5E_CANTRENAME, FAIL, "unable to move direct block")
+ if(H5AC_move_entry(f, H5AC_FHEAP_DBLOCK, par_iblock->ents[par_entry].addr, addr) < 0)
+ HGOTO_ERROR(H5E_HEAP, H5E_CANTMOVE, FAIL, "unable to move direct block")
/* Update information about compressed direct block's location & size */
par_iblock->ents[par_entry].addr = addr;
diff --git a/src/H5HFiblock.c b/src/H5HFiblock.c
index 917a450..949fdc6 100644
--- a/src/H5HFiblock.c
+++ b/src/H5HFiblock.c
@@ -565,8 +565,8 @@ H5HF_man_iblock_root_double(H5HF_hdr_t *hdr, hid_t dxpl_id, size_t min_dblock_si
/* Move object in cache, if it actually was relocated */
if(H5F_addr_ne(iblock->addr, new_addr)) {
- if(H5AC_rename(hdr->f, H5AC_FHEAP_IBLOCK, iblock->addr, new_addr) < 0)
- HGOTO_ERROR(H5E_HEAP, H5E_CANTRENAME, FAIL, "unable to move fractal heap root indirect block")
+ if(H5AC_move_entry(hdr->f, H5AC_FHEAP_IBLOCK, iblock->addr, new_addr) < 0)
+ HGOTO_ERROR(H5E_HEAP, H5E_CANTMOVE, FAIL, "unable to move fractal heap root indirect block")
iblock->addr = new_addr;
} /* end if */
@@ -724,7 +724,7 @@ H5HF_man_iblock_root_halve(H5HF_indirect_t *iblock, hid_t dxpl_id)
/* Move object in cache, if it actually was relocated */
if(H5F_addr_ne(iblock->addr, new_addr)) {
- if(H5AC_rename(hdr->f, H5AC_FHEAP_IBLOCK, iblock->addr, new_addr) < 0)
+ if(H5AC_move_entry(hdr->f, H5AC_FHEAP_IBLOCK, iblock->addr, new_addr) < 0)
HGOTO_ERROR(H5E_HEAP, H5E_CANTSPLIT, FAIL, "unable to move fractal heap root indirect block")
iblock->addr = new_addr;
} /* end if */
diff --git a/src/H5HL.c b/src/H5HL.c
index a360016..ecf409f 100644
--- a/src/H5HL.c
+++ b/src/H5HL.c
@@ -280,8 +280,8 @@ H5HL_dblk_realloc(H5F_t *f, hid_t dxpl_id, H5HL_t *heap, size_t new_heap_size)
HGOTO_ERROR(H5E_HEAP, H5E_CANTRESIZE, FAIL, "unable to resize heap data block in cache")
/* Relocate the heap data block in the cache */
- if(H5AC_rename(f, H5AC_LHEAP_DBLK, old_addr, new_addr) < 0)
- HGOTO_ERROR(H5E_HEAP, H5E_CANTRENAME, FAIL, "unable to move heap data block in cache")
+ if(H5AC_move_entry(f, H5AC_LHEAP_DBLK, old_addr, new_addr) < 0)
+ HGOTO_ERROR(H5E_HEAP, H5E_CANTMOVE, FAIL, "unable to move heap data block in cache")
} /* end else */
} /* end else */
diff --git a/src/H5err.txt b/src/H5err.txt
index 844bd57..275a8ff 100644
--- a/src/H5err.txt
+++ b/src/H5err.txt
@@ -159,7 +159,6 @@ MINOR, CACHE, H5E_PROTECT, Protected metadata error
MINOR, CACHE, H5E_NOTCACHED, Metadata not currently cached
MINOR, CACHE, H5E_SYSTEM, Internal error detected
MINOR, CACHE, H5E_CANTINS, Unable to insert metadata into cache
-MINOR, CACHE, H5E_CANTRENAME, Unable to rename metadata
MINOR, CACHE, H5E_CANTPROTECT, Unable to protect metadata
MINOR, CACHE, H5E_CANTUNPROTECT, Unable to unprotect metadata
MINOR, CACHE, H5E_CANTPIN, Unable to pin cache entry
@@ -191,6 +190,7 @@ MINOR, OHDR, H5E_CANTDELETE, Can't delete message
MINOR, OHDR, H5E_BADITER, Iteration failed
MINOR, OHDR, H5E_CANTPACK, Can't pack messages
MINOR, OHDR, H5E_CANTRESET, Can't reset object
+MINOR, OHDR, H5E_CANTRENAME, Unable to rename object
# Group related errors
MINOR, GROUP, H5E_CANTOPENOBJ, Can't open object
@@ -219,7 +219,7 @@ MINOR, PLIST, H5E_DUPCLASS, Duplicate class name in parent class
MINOR, LINK, H5E_TRAVERSE, Link traversal failure
MINOR, LINK, H5E_NLINKS, Too many soft links in path
MINOR, LINK, H5E_NOTREGISTERED, Link class not registered
-MINOR, LINK, H5E_CANTMOVE, Move callback returned error
+MINOR, LINK, H5E_CANTMOVE, Can't move object
MINOR, LINK, H5E_CANTSORT, Can't sort objects
# Parallel MPI errors
diff --git a/src/H5AC.c b/src/H5AC.c
index 5eced29..7f36fa0 100644
--- a/src/H5AC.c
+++ b/src/H5AC.c
@@ -91,7 +91,7 @@ H5FL_DEFINE_STATIC(H5AC_aux_t);
*
* addr: file offset of a metadata entry. Entries are added to this
* list (if they aren't there already) when they are marked
* dirty in an unprotect, inserted, or renamed. They are
* removed when they appear in a clean entries broadcast.
*
****************************************************************************/
@@ -189,7 +189,7 @@ static herr_t H5AC_receive_and_apply_clean_list(H5F_t * f,
hid_t secondary_dxpl_id,
H5AC_t * cache_ptr);
-static herr_t H5AC_log_renamed_entry(const H5F_t * f,
+static herr_t H5AC_log_moved_entry(const H5F_t * f,
haddr_t old_addr,
haddr_t new_addr);
#endif /* H5_HAVE_PARALLEL */
@@ -569,8 +569,8 @@ H5AC_create(const H5F_t *f,
aux_ptr->unprotect_dirty_bytes_updates = 0;
aux_ptr->insert_dirty_bytes = 0;
aux_ptr->insert_dirty_bytes_updates = 0;
- aux_ptr->rename_dirty_bytes = 0;
- aux_ptr->rename_dirty_bytes_updates = 0;
+ aux_ptr->move_dirty_bytes = 0;
+ aux_ptr->move_dirty_bytes_updates = 0;
#endif /* H5AC_DEBUG_DIRTY_BYTES_CREATION */
aux_ptr->d_slist_ptr = NULL;
aux_ptr->d_slist_len = 0;
@@ -903,7 +903,7 @@ done:
* The type and addr parameters are retained to avoid source
* code changed, but values other than NULL and HADDR_UNDEF
* respectively are errors. If all goes well, they should
* be removed, and the function renamed to something more
* descriptive -- perhaps H5AC_flush_cache.
*
* If the cache contains protected entries, the function will
@@ -1007,8 +1007,8 @@ H5AC_flush(H5F_t *f, hid_t dxpl_id, unsigned flags)
(int)(aux_ptr->unprotect_dirty_bytes_updates),
(int)(aux_ptr->insert_dirty_bytes),
(int)(aux_ptr->insert_dirty_bytes_updates),
- (int)(aux_ptr->rename_dirty_bytes),
- (int)(aux_ptr->rename_dirty_bytes_updates));
+ (int)(aux_ptr->move_dirty_bytes),
+ (int)(aux_ptr->move_dirty_bytes_updates));
#endif /* H5AC_DEBUG_DIRTY_BYTES_CREATION */
/* to prevent "messages from the future" we must synchronize all
@@ -1422,7 +1422,7 @@ done:
/*-------------------------------------------------------------------------
- * Function: H5AC_rename
+ * Function: H5AC_move_entry
*
* Purpose: Use this function to notify the cache that an object's
* file address changed.
@@ -1433,37 +1433,10 @@ done:
* matzke@llnl.gov
* Jul 9 1997
*
- * Modifications:
- * Robb Matzke, 1999-07-27
- * The OLD_ADDR and NEW_ADDR arguments are passed by value.
- *
- * JRM 5/17/04
- * Complete rewrite for the new meta-data cache.
- *
- * JRM - 6/7/04
- * Abstracted the guts of the function to H5C_rename_entry()
- * in H5C.c, and then re-wrote the function as a wrapper for
- * H5C_rename_entry().
- *
- * JRM - 7/5/05
- * Added code to track dirty byte generation, and to trigger
- * clean entry list propagation when it exceeds a user
- * specified threshold. Note that this code only applies in
- * the PHDF5 case. It should have no effect on either the
- * serial or FPHSD5 cases.
- *
- * Note that this code presumes that the renamed entry will
- * be present in all caches -- which it must be at present.
- * To maintain this invarient, only rename entries immediately
- * after you unprotect them.
- *
- * JRM - 6/6/06
- * Added trace file support.
- *
*-------------------------------------------------------------------------
*/
herr_t
-H5AC_rename(H5F_t *f, const H5AC_class_t *type, haddr_t old_addr, haddr_t new_addr)
+H5AC_move_entry(H5F_t *f, const H5AC_class_t *type, haddr_t old_addr, haddr_t new_addr)
{
herr_t result;
herr_t ret_value=SUCCEED; /* Return value */
@@ -1475,7 +1448,7 @@ H5AC_rename(H5F_t *f, const H5AC_class_t *type, haddr_t old_addr, haddr_t new_ad
FILE * trace_file_ptr = NULL;
#endif /* H5AC__TRACE_FILE_ENABLED */
- FUNC_ENTER_NOAPI(H5AC_rename, FAIL)
+ FUNC_ENTER_NOAPI(H5AC_move_entry, FAIL)
HDassert(f);
HDassert(f->shared->cache);
@@ -1485,7 +1458,7 @@ H5AC_rename(H5F_t *f, const H5AC_class_t *type, haddr_t old_addr, haddr_t new_ad
HDassert(H5F_addr_ne(old_addr, new_addr));
#if H5AC__TRACE_FILE_ENABLED
/* For the rename call, only the old addr and new addr are really
* necessary in the trace file. Include the type id so we don't have to
* look it up. Also write the result to catch occult errors.
*/
@@ -1495,7 +1468,7 @@ H5AC_rename(H5F_t *f, const H5AC_class_t *type, haddr_t old_addr, haddr_t new_ad
( H5C_get_trace_file_ptr(f->shared->cache, &trace_file_ptr) >= 0) &&
( trace_file_ptr != NULL ) ) {
- sprintf(trace, "H5AC_rename 0x%lx 0x%lx %d",
+ sprintf(trace, "H5AC_move_entry 0x%lx 0x%lx %d",
(unsigned long)old_addr,
(unsigned long)new_addr,
(int)(type->id));
@@ -1504,20 +1477,20 @@ H5AC_rename(H5F_t *f, const H5AC_class_t *type, haddr_t old_addr, haddr_t new_ad
#ifdef H5_HAVE_PARALLEL
if ( NULL != (aux_ptr = f->shared->cache->aux_ptr) ) {
- if(H5AC_log_renamed_entry(f, old_addr, new_addr) < 0)
- HGOTO_ERROR(H5E_CACHE, H5E_CANTUNPROTECT, FAIL, "can't log renamed entry")
+ if(H5AC_log_moved_entry(f, old_addr, new_addr) < 0)
+ HGOTO_ERROR(H5E_CACHE, H5E_CANTUNPROTECT, FAIL, "can't log moved entry")
}
#endif /* H5_HAVE_PARALLEL */
- result = H5C_rename_entry(f->shared->cache,
+ result = H5C_move_entry(f->shared->cache,
type,
old_addr,
new_addr);
if ( result < 0 ) {
- HGOTO_ERROR(H5E_CACHE, H5E_CANTRENAME, FAIL, \
- "H5C_rename_entry() failed.")
+ HGOTO_ERROR(H5E_CACHE, H5E_CANTMOVE, FAIL, \
+ "H5C_move_entry() failed.")
}
#ifdef H5_HAVE_PARALLEL
@@ -1547,7 +1520,7 @@ done:
FUNC_LEAVE_NOAPI(ret_value)
-} /* H5AC_rename() */
+} /* H5AC_move_entry() */
/*-------------------------------------------------------------------------
@@ -3905,15 +3878,15 @@ done:
/*-------------------------------------------------------------------------
*
- * Function: H5AC_log_renamed_entry()
+ * Function: H5AC_log_moved_entry()
*
* Purpose: Update the dirty_bytes count for a renamed entry.
*
* WARNING
*
* At present, the way that the rename call is used ensures
* that the renamed entry is present in all caches by
* renaming in a collective operation and immediately after
* unprotecting the target entry.
*
* This function uses this invarient, and will cause arcane
@@ -3921,17 +3894,17 @@ done:
* becomes impossible, we will have to rework this function
* extensively, and likely include a bit of IPC for
* synchronization. A better option might be to subsume
* rename in the unprotect operation.
*
* Given that the target entry is in all caches, the function
* proceeds as follows:
*
* For processes with mpi rank other 0, it simply checks to
* see if the entry was dirty prior to the rename, and adds
* the entries size to the dirty bytes count.
*
* In the process with mpi rank 0, the function first checks
* to see if the entry was dirty prior to the rename. If it
* was, and if the entry doesn't appear in the dirtied list
* under its old address, it adds the entry's size to the
* dirty bytes count.
@@ -3953,7 +3926,7 @@ done:
*/
#ifdef H5_HAVE_PARALLEL
static herr_t
-H5AC_log_renamed_entry(const H5F_t *f,
+H5AC_log_moved_entry(const H5F_t *f,
haddr_t old_addr,
haddr_t new_addr)
{
@@ -3965,7 +3938,7 @@ H5AC_log_renamed_entry(const H5F_t *f,
H5AC_slist_entry_t * slist_entry_ptr = NULL;
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI(H5AC_log_renamed_entry, FAIL)
+ FUNC_ENTER_NOAPI(H5AC_log_moved_entry, FAIL)
HDassert( f );
HDassert( f->shared );
@@ -4070,8 +4043,8 @@ H5AC_log_renamed_entry(const H5F_t *f,
aux_ptr->dirty_bytes += entry_size;
#if H5AC_DEBUG_DIRTY_BYTES_CREATION
- aux_ptr->rename_dirty_bytes += entry_size;
- aux_ptr->rename_dirty_bytes_updates += 1;
+ aux_ptr->move_dirty_bytes += entry_size;
+ aux_ptr->move_dirty_bytes_updates += 1;
#endif /* H5AC_DEBUG_DIRTY_BYTES_CREATION */
}
@@ -4097,8 +4070,8 @@ H5AC_log_renamed_entry(const H5F_t *f,
aux_ptr->dirty_bytes += entry_size;
#if H5AC_DEBUG_DIRTY_BYTES_CREATION
- aux_ptr->rename_dirty_bytes += entry_size;
- aux_ptr->rename_dirty_bytes_updates += 1;
+ aux_ptr->move_dirty_bytes += entry_size;
+ aux_ptr->move_dirty_bytes_updates += 1;
#endif /* H5AC_DEBUG_DIRTY_BYTES_CREATION */
}
@@ -4106,7 +4079,7 @@ done:
FUNC_LEAVE_NOAPI(ret_value)
-} /* H5AC_log_renamed_entry() */
+} /* H5AC_log_moved_entry() */
#endif /* H5_HAVE_PARALLEL */
@@ -4214,8 +4187,8 @@ H5AC_propagate_flushed_and_still_clean_entries_list(H5F_t * f,
(int)(aux_ptr->unprotect_dirty_bytes_updates),
(int)(aux_ptr->insert_dirty_bytes),
(int)(aux_ptr->insert_dirty_bytes_updates),
- (int)(aux_ptr->rename_dirty_bytes),
- (int)(aux_ptr->rename_dirty_bytes_updates));
+ (int)(aux_ptr->move_dirty_bytes),
+ (int)(aux_ptr->move_dirty_bytes_updates));
#endif /* H5AC_DEBUG_DIRTY_BYTES_CREATION */
if ( do_barrier ) {
@@ -4276,8 +4249,8 @@ H5AC_propagate_flushed_and_still_clean_entries_list(H5F_t * f,
aux_ptr->unprotect_dirty_bytes_updates = 0;
aux_ptr->insert_dirty_bytes = 0;
aux_ptr->insert_dirty_bytes_updates = 0;
- aux_ptr->rename_dirty_bytes = 0;
- aux_ptr->rename_dirty_bytes_updates = 0;
+ aux_ptr->move_dirty_bytes = 0;
+ aux_ptr->move_dirty_bytes_updates = 0;
#endif /* H5AC_DEBUG_DIRTY_BYTES_CREATION */
done:
@@ -91,7 +91,7 @@ H5FL_DEFINE_STATIC(H5AC_aux_t);
* addr: file offset of a metadata entry. Entries are added to this
* list (if they aren't there already) when they are marked
- * dirty in an unprotect, inserted, or renamed. They are
+ * dirty in an unprotect, inserted, or moved. They are
* removed when they appear in a clean entries broadcast.
*
@@ -903,7 +903,7 @@ done:
* code changed, but values other than NULL and HADDR_UNDEF
* respectively are errors. If all goes well, they should
- * be removed, and the function renamed to something more
+ * be removed, and the function moved to something more
* descriptive -- perhaps H5AC_flush_cache.
*
@@ -1485,7 +1458,7 @@ H5AC_rename(H5F_t *f, const H5AC_class_t *type, haddr_t old_addr, haddr_t new_ad
HDassert(H5F_addr_ne(old_addr, new_addr));
#if H5AC__TRACE_FILE_ENABLED
- /* For the rename call, only the old addr and new addr are really
+ /* For the move call, only the old addr and new addr are really
* necessary in the trace file. Include the type id so we don't have to
* look it up. Also write the result to catch occult errors.
@@ -3905,15 +3878,15 @@ done:
*
- * Purpose: Update the dirty_bytes count for a renamed entry.
+ * Purpose: Update the dirty_bytes count for a moved entry.
*
* WARNING
@@ -3905,15 +3878,15 @@ done:
* WARNING
*
- * At present, the way that the rename call is used ensures
- * that the renamed entry is present in all caches by
- * renaming in a collective operation and immediately after
+ * At present, the way that the move call is used ensures
+ * that the moved entry is present in all caches by
+ * moving in a collective operation and immediately after
* unprotecting the target entry.
*
@@ -3921,17 +3894,17 @@ done:
* extensively, and likely include a bit of IPC for
* synchronization. A better option might be to subsume
- * rename in the unprotect operation.
+ * move in the unprotect operation.
*
* Given that the target entry is in all caches, the function
@@ -3921,17 +3894,17 @@ done:
*
* For processes with mpi rank other 0, it simply checks to
- * see if the entry was dirty prior to the rename, and adds
+ * see if the entry was dirty prior to the move, and adds
* the entries size to the dirty bytes count.
*
@@ -3921,17 +3894,17 @@ done:
*
* In the process with mpi rank 0, the function first checks
- * to see if the entry was dirty prior to the rename. If it
+ * to see if the entry was dirty prior to the move. If it
* was, and if the entry doesn't appear in the dirtied list
* under its old address, it adds the entry's size to the
diff --git a/src/H5ACpkg.h b/src/H5ACpkg.h
index 911aceb..d5346f5 100644
--- a/src/H5ACpkg.h
+++ b/src/H5ACpkg.h
@@ -107,7 +107,7 @@
*
* Maintaining this count is easy for all processes not on process 0 --
* all that is necessary is to add the size of the entry to the total
* whenever there is an insertion, a rename of a previously clean entry,
* or whever a previously clean entry is marked dirty in an unprotect.
*
* On process 0, we have to be careful not to count dirty bytes twice.
@@ -197,18 +197,18 @@
* been created via insert operations since the last time
* the cleaned list was propagated.
*
* rename_dirty_bytes: This field only exists when the
* H5AC_DEBUG_DIRTY_BYTES_CREATION #define is TRUE.
*
* It is used to track the number of dirty bytes created
* via rename operations since the last time the cleaned
* list was propagated.
*
* rename_dirty_bytes_updates: This field only exists when the
* H5AC_DEBUG_DIRTY_BYTES_CREATION #define is TRUE.
*
* It is used to track the number of times dirty bytes have
* been created via rename operations since the last time
* the cleaned list was propagated.
*
* d_slist_ptr: Pointer to an instance of H5SL_t used to maintain a list
@@ -224,7 +224,7 @@
*
* 1) an entry is inserted in the metadata cache, or
*
- * 2) a previously clean entry is renamed, and it does not
+ * 2) a previously clean entry is moved, and it does not
* already appear in the dirty entry list, or
*
* 3) a previously clean entry is unprotected with the
@@ -234,7 +234,7 @@
* Entries are added to the dirty entry list whever they cause
* the dirty bytes count to be increased. They are removed
* when they appear in a clean entries broadcast. Note that
- * renames must be reflected in the dirty entry list.
+ * moves must be reflected in the dirty entry list.
*
* To reitterate, this field is only used on process 0 -- it
* should be NULL on all other processes.
@@ -303,8 +303,8 @@ typedef struct H5AC_aux_t
int32_t insert_dirty_bytes;
int32_t insert_dirty_bytes_updates;
- int32_t rename_dirty_bytes;
- int32_t rename_dirty_bytes_updates;
+ int32_t move_dirty_bytes;
+ int32_t move_dirty_bytes_updates;
#endif /* H5AC_DEBUG_DIRTY_BYTES_CREATION */
@@ -107,7 +107,7 @@
* Maintaining this count is easy for all processes not on process 0 --
* all that is necessary is to add the size of the entry to the total
- * whenever there is an insertion, a rename of a previously clean entry,
+ * whenever there is an insertion, a move of a previously clean entry,
* or whever a previously clean entry is marked dirty in an unprotect.
*
@@ -197,18 +197,18 @@
* the cleaned list was propagated.
*
- * rename_dirty_bytes: This field only exists when the
+ * move_dirty_bytes: This field only exists when the
* H5AC_DEBUG_DIRTY_BYTES_CREATION #define is TRUE.
*
@@ -197,18 +197,18 @@
*
* It is used to track the number of dirty bytes created
- * via rename operations since the last time the cleaned
+ * via move operations since the last time the cleaned
* list was propagated.
*
@@ -197,18 +197,18 @@
* list was propagated.
*
- * rename_dirty_bytes_updates: This field only exists when the
+ * move_dirty_bytes_updates: This field only exists when the
* H5AC_DEBUG_DIRTY_BYTES_CREATION #define is TRUE.
*
@@ -197,18 +197,18 @@
*
* It is used to track the number of times dirty bytes have
- * been created via rename operations since the last time
+ * been created via move operations since the last time
* the cleaned list was propagated.
*
diff --git a/src/H5C.c b/src/H5C.c
index 735fd09..b8e1357 100644
--- a/src/H5C.c
+++ b/src/H5C.c
@@ -1125,7 +1125,7 @@ done:
* H5C_t.
*
* Also reworked function to allow for the possibility that
* entries will be dirtied, resized, or renamed during flush
* callbacks. As a result, we may have to make multiple
* passes through the skip list before the cache is flushed.
*
@@ -1259,7 +1259,7 @@ H5C_flush_cache(H5F_t *f, hid_t primary_dxpl_id, hid_t secondary_dxpl_id, unsign
*
* To make things more entertaining, with the advent of the
* fractal heap, the entry flush callback can cause entries
* to be dirtied, resized, and/or renamed.
*
* To deal with this, we first make note of the initial
* skip list length and size:
@@ -2804,7 +2804,7 @@ done:
/*-------------------------------------------------------------------------
*
- * Function: H5C_rename_entry
+ * Function: H5C_move_entry
*
* Purpose: Use this function to notify the cache that an entry's
* file address changed.
@@ -2814,36 +2814,10 @@ done:
* Programmer: John Mainzer
* 6/2/04
*
- * Modifications:
- *
- * JRM -- 7/21/04
- * Updated function for the addition of the hash table.
- *
- * JRM -- 6/6/05
- * Updated function to force all renamed entries to be
- * dirty. This is part of a series of code modifications
- * moving management of the is_dirty field of
- * H5C_cache_entry_t into the H5C code.
- *
- * JRM -- 4/3/06
- * Updated function to disallow renaming of pinned entries.
- *
- * JRM -- 4/27/06
- * Updated function to support renaming of pinned entries.
- *
- * JRM -- 8/24/06
- * Updated function to refrain from altering the index, the
- * replacement policy data structures, and skip list when
- * the function is called within the flush callback for the
- * target entry and the target entry is being destroyed.
- *
- * Note that in this case H5C_flush_single_entry() will handle
- * all these details for us.
- *
*-------------------------------------------------------------------------
*/
herr_t
-H5C_rename_entry(H5C_t * cache_ptr,
+H5C_move_entry(H5C_t * cache_ptr,
const H5C_class_t * type,
haddr_t old_addr,
haddr_t new_addr)
@@ -2856,7 +2830,7 @@ H5C_rename_entry(H5C_t * cache_ptr,
#endif /* H5C_DO_SANITY_CHECKS */
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI(H5C_rename_entry, FAIL)
+ FUNC_ENTER_NOAPI(H5C_move_entry, FAIL)
HDassert( cache_ptr );
HDassert( cache_ptr->magic == H5C__H5C_T_MAGIC );
@@ -2886,7 +2860,7 @@ H5C_rename_entry(H5C_t * cache_ptr,
if ( entry_ptr->is_protected ) {
- HGOTO_ERROR(H5E_CACHE, H5E_CANTRENAME, FAIL, \
+ HGOTO_ERROR(H5E_CACHE, H5E_CANTMOVE, FAIL, \
"Target entry is protected.")
}
@@ -2896,12 +2870,12 @@ H5C_rename_entry(H5C_t * cache_ptr,
if ( test_entry_ptr->type == type ) {
- HGOTO_ERROR(H5E_CACHE, H5E_CANTRENAME, FAIL, \
- "Target already renamed & reinserted???.")
+ HGOTO_ERROR(H5E_CACHE, H5E_CANTMOVE, FAIL, \
+ "Target already moved & reinserted???.")
} else {
- HGOTO_ERROR(H5E_CACHE, H5E_CANTRENAME, FAIL, \
+ HGOTO_ERROR(H5E_CACHE, H5E_CANTMOVE, FAIL, \
"New address already in use?.")
}
@@ -2912,7 +2886,7 @@ H5C_rename_entry(H5C_t * cache_ptr,
* new address, mark it as dirty (if it isn't already) and then re-insert.
*
* Update the replacement policy for a hit to avoid an eviction before
* the renamed entry is touched. Update stats for a rename.
*
* Note that we do not check the size of the cache, or evict anything.
* Since this is a simple re-name, cache size should be unaffected.
@@ -2976,11 +2950,11 @@ H5C_rename_entry(H5C_t * cache_ptr,
#endif /* H5C_DO_SANITY_CHECKS */
- H5C__UPDATE_RP_FOR_RENAME(cache_ptr, entry_ptr, was_dirty, FAIL)
+ H5C__UPDATE_RP_FOR_MOVE(cache_ptr, entry_ptr, was_dirty, FAIL)
}
}
- H5C__UPDATE_STATS_FOR_RENAME(cache_ptr, entry_ptr)
+ H5C__UPDATE_STATS_FOR_MOVE(cache_ptr, entry_ptr)
done:
@@ -2994,7 +2968,7 @@ done:
FUNC_LEAVE_NOAPI(ret_value)
-} /* H5C_rename_entry() */
+} /* H5C_move_entry() */
/*-------------------------------------------------------------------------
@@ -4144,9 +4118,9 @@ H5C_stats(H5C_t * cache_ptr,
int64_t total_clears = 0;
int64_t total_flushes = 0;
int64_t total_evictions = 0;
- int64_t total_renames = 0;
- int64_t total_entry_flush_renames = 0;
- int64_t total_cache_flush_renames = 0;
+ int64_t total_moves = 0;
+ int64_t total_entry_flush_moves = 0;
+ int64_t total_cache_flush_moves = 0;
int64_t total_size_increases = 0;
int64_t total_size_decreases = 0;
int64_t total_entry_flush_size_changes = 0;
@@ -4195,11 +4169,11 @@ H5C_stats(H5C_t * cache_ptr,
total_clears += cache_ptr->clears[i];
total_flushes += cache_ptr->flushes[i];
total_evictions += cache_ptr->evictions[i];
- total_renames += cache_ptr->renames[i];
- total_entry_flush_renames
- += cache_ptr->entry_flush_renames[i];
- total_cache_flush_renames
- += cache_ptr->cache_flush_renames[i];
+ total_moves += cache_ptr->moves[i];
+ total_entry_flush_moves
+ += cache_ptr->entry_flush_moves[i];
+ total_cache_flush_moves
+ += cache_ptr->cache_flush_moves[i];
total_size_increases += cache_ptr->size_increases[i];
total_size_decreases += cache_ptr->size_decreases[i];
total_entry_flush_size_changes
@@ -4347,17 +4321,17 @@ H5C_stats(H5C_t * cache_ptr,
(long)total_evictions);
HDfprintf(stdout,
- "%s Total insertions(pinned) / renames = %ld(%ld) / %ld\n",
+ "%s Total insertions(pinned) / moves = %ld(%ld) / %ld\n",
cache_ptr->prefix,
(long)total_insertions,
(long)total_pinned_insertions,
- (long)total_renames);
+ (long)total_moves);
HDfprintf(stdout,
- "%s Total entry / cache flush renames = %ld / %ld\n",
+ "%s Total entry / cache flush moves = %ld / %ld\n",
cache_ptr->prefix,
- (long)total_entry_flush_renames,
- (long)total_cache_flush_renames);
+ (long)total_entry_flush_moves,
+ (long)total_cache_flush_moves);
HDfprintf(stdout, "%s Total entry size incrs / decrs = %ld / %ld\n",
cache_ptr->prefix,
@@ -4441,17 +4415,17 @@ H5C_stats(H5C_t * cache_ptr,
(long)(cache_ptr->evictions[i]));
HDfprintf(stdout,
- "%s insertions(pinned) / renames = %ld(%ld) / %ld\n",
+ "%s insertions(pinned) / moves = %ld(%ld) / %ld\n",
cache_ptr->prefix,
(long)(cache_ptr->insertions[i]),
(long)(cache_ptr->pinned_insertions[i]),
- (long)(cache_ptr->renames[i]));
+ (long)(cache_ptr->moves[i]));
HDfprintf(stdout,
- "%s entry / cache flush renames = %ld / %ld\n",
+ "%s entry / cache flush moves = %ld / %ld\n",
cache_ptr->prefix,
- (long)(cache_ptr->entry_flush_renames[i]),
- (long)(cache_ptr->cache_flush_renames[i]));
+ (long)(cache_ptr->entry_flush_moves[i]),
+ (long)(cache_ptr->cache_flush_moves[i]));
HDfprintf(stdout,
"%s size increases / decreases = %ld / %ld\n",
@@ -4583,9 +4557,9 @@ H5C_stats__reset(H5C_t UNUSED * cache_ptr)
cache_ptr->clears[i] = 0;
cache_ptr->flushes[i] = 0;
cache_ptr->evictions[i] = 0;
- cache_ptr->renames[i] = 0;
- cache_ptr->entry_flush_renames[i] = 0;
- cache_ptr->cache_flush_renames[i] = 0;
+ cache_ptr->moves[i] = 0;
+ cache_ptr->entry_flush_moves[i] = 0;
+ cache_ptr->cache_flush_moves[i] = 0;
cache_ptr->pins[i] = 0;
cache_ptr->unpins[i] = 0;
cache_ptr->dirty_pins[i] = 0;
@@ -6753,7 +6727,7 @@ done:
* Modifications:
*
* To support the fractal heap, the cache must now deal with
* entries being dirtied, resized, and/or renamed inside
* flush callbacks. Updated function to support this.
*
* -- JRM 8/27/06
@@ -6837,14 +6811,14 @@ H5C_flush_invalidate_cache(const H5F_t * f,
* unpin themselves, or until the number of pinned entries stops
* declining. In this later case, we scream and die.
*
* Since the fractal heap can dirty, resize, and/or rename entries
* in is flush callback, it is possible that the cache will still
* contain dirty entries at this point. If so, we must make up to
* H5C__MAX_PASSES_ON_FLUSH more passes through the skip list
* to allow it to empty. If is is not empty at this point, we again
* scream and die.
*
* Further, since clean entries can be dirtied, resized, and/or renamed
* as the result of a flush call back (either the entries own, or that
* for some other cache entry), we can no longer promise to flush
* the cache entries in increasing address order.
@@ -6915,7 +6889,7 @@ H5C_flush_invalidate_cache(const H5F_t * f,
initial_slist_size = cache_ptr->slist_size;
/* There is also the possibility that entries will be
* dirtied, resized, and/or renamed as the result of
* calls to the flush callbacks. We use the slist_len_increase
* and slist_size_increase increase fields in struct H5C_t
* to track these changes for purpose of sanity checking.
@@ -7350,7 +7324,7 @@ done:
*
* Also added flush_flags parameter to the call to
* type_ptr->flush() so that the flush routine can report
* whether the entry has been resized or renamed. Added
* code using the flush_flags variable to detect the case
* in which the target entry is resized during flush, and
* update the caches data structures accordingly.
@@ -7517,8 +7491,8 @@ H5C_flush_single_entry(const H5F_t * f,
* We must do deletions now as the callback routines will free the
* entry if destroy is true.
*
* Note that it is possible that the entry will be renamed during
* its call to flush. This will upset H5C_rename_entry() if we
* don't tell it that it doesn't have to worry about updating the
* index and SLIST. Use the destroy_in_progress field for this
* purpose.
@@ -7760,9 +7734,9 @@ H5C_flush_single_entry(const H5F_t * f,
* change this test accordingly.
*
* NB: While this test detects entryies that attempt
* to resize or rename themselves during a flush
* in the parallel case, it will not detect an
* entry that dirties, resizes, and/or renames
* other entries during its flush.
*
* From what Quincey tells me, this test is
@@ -7775,7 +7749,7 @@ H5C_flush_single_entry(const H5F_t * f,
if ( cache_ptr->aux_ptr != NULL ) {
HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, \
- "resize/rename in serialize occured in parallel case.")
+ "resize/move in serialize occured in parallel case.")
}
}
@@ -7846,9 +7820,9 @@ H5C_flush_single_entry(const H5F_t * f,
}
}
- if ( (flush_flags & H5C_CALLBACK__RENAMED_FLAG) != 0 ) {
+ if ( (flush_flags & H5C_CALLBACK__MOVED_FLAG) != 0 ) {
- /* The entry was renamed as the result of the flush.
+ /* The entry was moved as the result of the flush.
*
* Most likely, the entry was compressed, and the
* new version is larger than the old and thus had
@@ -1125,7 +1125,7 @@ done:
*
* Also reworked function to allow for the possibility that
- * entries will be dirtied, resized, or renamed during flush
+ * entries will be dirtied, resized, or moved during flush
* callbacks. As a result, we may have to make multiple
* passes through the skip list before the cache is flushed.
@@ -1259,7 +1259,7 @@ H5C_flush_cache(H5F_t *f, hid_t primary_dxpl_id, hid_t secondary_dxpl_id, unsign
* To make things more entertaining, with the advent of the
* fractal heap, the entry flush callback can cause entries
- * to be dirtied, resized, and/or renamed.
+ * to be dirtied, resized, and/or moved.
*
* To deal with this, we first make note of the initial
@@ -2912,7 +2886,7 @@ H5C_rename_entry(H5C_t * cache_ptr,
*
* Update the replacement policy for a hit to avoid an eviction before
- * the renamed entry is touched. Update stats for a rename.
+ * the moved entry is touched. Update stats for a move.
*
* Note that we do not check the size of the cache, or evict anything.
@@ -6753,7 +6727,7 @@ done:
*
* To support the fractal heap, the cache must now deal with
- * entries being dirtied, resized, and/or renamed inside
+ * entries being dirtied, resized, and/or moved inside
* flush callbacks. Updated function to support this.
*
@@ -6837,14 +6811,14 @@ H5C_flush_invalidate_cache(const H5F_t * f,
* declining. In this later case, we scream and die.
*
- * Since the fractal heap can dirty, resize, and/or rename entries
+ * Since the fractal heap can dirty, resize, and/or move entries
* in is flush callback, it is possible that the cache will still
* contain dirty entries at this point. If so, we must make up to
@@ -6837,14 +6811,14 @@ H5C_flush_invalidate_cache(const H5F_t * f,
* scream and die.
*
- * Further, since clean entries can be dirtied, resized, and/or renamed
+ * Further, since clean entries can be dirtied, resized, and/or moved
* as the result of a flush call back (either the entries own, or that
* for some other cache entry), we can no longer promise to flush
@@ -6915,7 +6889,7 @@ H5C_flush_invalidate_cache(const H5F_t * f,
initial_slist_size = cache_ptr->slist_size;
/* There is also the possibility that entries will be
- * dirtied, resized, and/or renamed as the result of
+ * dirtied, resized, and/or moved as the result of
* calls to the flush callbacks. We use the slist_len_increase
* and slist_size_increase increase fields in struct H5C_t
@@ -7350,7 +7324,7 @@ done:
* Also added flush_flags parameter to the call to
* type_ptr->flush() so that the flush routine can report
- * whether the entry has been resized or renamed. Added
+ * whether the entry has been resized or moved. Added
* code using the flush_flags variable to detect the case
* in which the target entry is resized during flush, and
@@ -7517,8 +7491,8 @@ H5C_flush_single_entry(const H5F_t * f,
* entry if destroy is true.
*
- * Note that it is possible that the entry will be renamed during
- * its call to flush. This will upset H5C_rename_entry() if we
+ * Note that it is possible that the entry will be moved during
+ * its call to flush. This will upset H5C_move_entry() if we
* don't tell it that it doesn't have to worry about updating the
* index and SLIST. Use the destroy_in_progress field for this
@@ -7760,9 +7734,9 @@ H5C_flush_single_entry(const H5F_t * f,
*
* NB: While this test detects entryies that attempt
- * to resize or rename themselves during a flush
+ * to resize or move themselves during a flush
* in the parallel case, it will not detect an
@@ -7760,9 +7734,9 @@ H5C_flush_single_entry(const H5F_t * f,
* in the parallel case, it will not detect an
- * entry that dirties, resizes, and/or renames
+ * entry that dirties, resizes, and/or moves
* other entries during its flush.
*
diff --git a/src/H5Cpkg.h b/src/H5Cpkg.h
index 2812fa8..765dc5b 100644
--- a/src/H5Cpkg.h
+++ b/src/H5Cpkg.h
@@ -44,7 +44,7 @@
#include "H5SLprivate.h" /* Skip lists */
/* With the introduction of the fractal heap, it is now possible for
- * entries to be dirtied, resized, and/or renamed in the flush callbacks.
+ * entries to be dirtied, resized, and/or moved in the flush callbacks.
* As a result, on flushes, it may be necessary to make multiple passes
* through the slist before it is empty. The H5C__MAX_PASSES_ON_FLUSH
* #define is used to set an upper limit on the number of passes.
@@ -251,7 +251,7 @@
* some optimizations when I get to it.
*
* With the addition of the fractal heap, the cache must now deal with
- * the case in which entries may be dirtied, renamed, or have their sizes
+ * the case in which entries may be dirtied, moved, or have their sizes
* changed during a flush. To allow sanity checks in this situation, the
* following two fields have been added. They are only compiled in when
* H5C_DO_SANITY_CHECKS is TRUE.
@@ -637,19 +637,19 @@
* equal to the array index has been evicted from the cache in
* the current epoch.
*
* renames: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1. The cells
* are used to record the number of times an entry with type
- * id equal to the array index has been renamed in the current
+ * id equal to the array index has been moved in the current
* epoch.
*
* entry_flush_renames: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1.
* The cells are used to record the number of times an entry
- * with type id equal to the array index has been renamed
+ * with type id equal to the array index has been moved
* during its flush callback in the current epoch.
*
* cache_flush_renames: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1.
* The cells are used to record the number of times an entry
- * with type id equal to the array index has been renamed
+ * with type id equal to the array index has been moved
* during a cache flush in the current epoch.
*
* pins: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1. The cells
@@ -902,9 +902,9 @@ struct H5C_t
int64_t clears[H5C__MAX_NUM_TYPE_IDS + 1];
int64_t flushes[H5C__MAX_NUM_TYPE_IDS + 1];
int64_t evictions[H5C__MAX_NUM_TYPE_IDS + 1];
- int64_t renames[H5C__MAX_NUM_TYPE_IDS + 1];
- int64_t entry_flush_renames[H5C__MAX_NUM_TYPE_IDS + 1];
- int64_t cache_flush_renames[H5C__MAX_NUM_TYPE_IDS + 1];
+ int64_t moves[H5C__MAX_NUM_TYPE_IDS + 1];
+ int64_t entry_flush_moves[H5C__MAX_NUM_TYPE_IDS + 1];
+ int64_t cache_flush_moves[H5C__MAX_NUM_TYPE_IDS + 1];
int64_t pins[H5C__MAX_NUM_TYPE_IDS + 1];
int64_t unpins[H5C__MAX_NUM_TYPE_IDS + 1];
int64_t dirty_pins[H5C__MAX_NUM_TYPE_IDS + 1];
@@ -1409,14 +1409,14 @@ if ( ( (entry_ptr) == NULL ) || \
if ( (cache_ptr)->pel_size > (cache_ptr)->max_pel_size ) \
(cache_ptr)->max_pel_size = (cache_ptr)->pel_size;
-#define H5C__UPDATE_STATS_FOR_RENAME(cache_ptr, entry_ptr) \
+#define H5C__UPDATE_STATS_FOR_MOVE(cache_ptr, entry_ptr) \
if ( cache_ptr->flush_in_progress ) { \
- ((cache_ptr)->cache_flush_renames[(entry_ptr)->type->id])++; \
+ ((cache_ptr)->cache_flush_moves[(entry_ptr)->type->id])++; \
} \
if ( entry_ptr->flush_in_progress ) { \
- ((cache_ptr)->entry_flush_renames[(entry_ptr)->type->id])++; \
+ ((cache_ptr)->entry_flush_moves[(entry_ptr)->type->id])++; \
} \
- (((cache_ptr)->renames)[(entry_ptr)->type->id])++;
+ (((cache_ptr)->moves)[(entry_ptr)->type->id])++;
#define H5C__UPDATE_STATS_FOR_ENTRY_SIZE_CHANGE(cache_ptr, entry_ptr, new_size)\
if ( cache_ptr->flush_in_progress ) { \
@@ -1649,7 +1649,7 @@ if ( ( (entry_ptr) == NULL ) || \
#define H5C__RESET_CACHE_ENTRY_STATS(entry_ptr)
#define H5C__UPDATE_STATS_FOR_DIRTY_PIN(cache_ptr, entry_ptr)
#define H5C__UPDATE_STATS_FOR_UNPROTECT(cache_ptr)
-#define H5C__UPDATE_STATS_FOR_RENAME(cache_ptr, entry_ptr)
+#define H5C__UPDATE_STATS_FOR_MOVE(cache_ptr, entry_ptr)
#define H5C__UPDATE_STATS_FOR_ENTRY_SIZE_CHANGE(cache_ptr, entry_ptr, new_size)
#define H5C__UPDATE_STATS_FOR_HT_INSERTION(cache_ptr)
#define H5C__UPDATE_STATS_FOR_HT_DELETION(cache_ptr)
@@ -1967,7 +1967,7 @@ if ( ( (cache_ptr) == NULL ) || \
* checks in the flush routines.
*
* All this is needed as the fractal heap needs to be
- * able to dirty, resize and/or rename entries during the
+ * able to dirty, resize and/or move entries during the
* flush.
*
*-------------------------------------------------------------------------
@@ -2106,7 +2106,7 @@ if ( ( (cache_ptr) == NULL ) || \
* that are used in sanity checks in the flush routines.
*
* All this is needed as the fractal heap needs to be
- * able to dirty, resize and/or rename entries during the
+ * able to dirty, resize and/or move entries during the
* flush.
*
*-------------------------------------------------------------------------
@@ -2849,10 +2849,10 @@ if ( ( (cache_ptr) == NULL ) || \
/*-------------------------------------------------------------------------
*
- * Macro: H5C__UPDATE_RP_FOR_RENAME
+ * Macro: H5C__UPDATE_RP_FOR_MOVE
*
* Purpose: Update the replacement policy data structures for a
- * rename of the specified cache entry.
+ * move of the specified cache entry.
*
* At present, we only support the modified LRU policy, so
* this function deals with that case unconditionally. If
@@ -2866,8 +2866,8 @@ if ( ( (cache_ptr) == NULL ) || \
* Modifications:
*
* JRM - 7/27/04
- * Converted the function H5C_update_rp_for_rename() to the
- * macro H5C__UPDATE_RP_FOR_RENAME in an effort to squeeze
+ * Converted the function H5C_update_rp_for_move() to the
+ * macro H5C__UPDATE_RP_FOR_MOVE in an effort to squeeze
* a bit more performance out of the cache.
*
* At least for the first cut, I am leaving the comments and
@@ -2881,11 +2881,11 @@ if ( ( (cache_ptr) == NULL ) || \
*
* JRM - 6/23/05
* Added the was_dirty parameter. It is possible that
- * the entry was clean when it was renamed -- if so it
+ * the entry was clean when it was moved -- if so it
* it is in the clean LRU regardless of the current
* value of the is_dirty field.
*
- * At present, all renamed entries are forced to be
+ * At present, all moved entries are forced to be
* dirty. This macro is a bit more general that that,
* to allow it to function correctly should that policy
* be relaxed in the future.
@@ -2905,7 +2905,7 @@ if ( ( (cache_ptr) == NULL ) || \
#if H5C_MAINTAIN_CLEAN_AND_DIRTY_LRU_LISTS
-#define H5C__UPDATE_RP_FOR_RENAME(cache_ptr, entry_ptr, was_dirty, fail_val) \
+#define H5C__UPDATE_RP_FOR_MOVE(cache_ptr, entry_ptr, was_dirty, fail_val) \
{ \
HDassert( (cache_ptr) ); \
HDassert( (cache_ptr)->magic == H5C__H5C_T_MAGIC ); \
@@ -2979,11 +2979,11 @@ if ( ( (cache_ptr) == NULL ) || \
\
/* End modified LRU specific code. */ \
} \
-} /* H5C__UPDATE_RP_FOR_RENAME */
+} /* H5C__UPDATE_RP_FOR_MOVE */
#else /* H5C_MAINTAIN_CLEAN_AND_DIRTY_LRU_LISTS */
-#define H5C__UPDATE_RP_FOR_RENAME(cache_ptr, entry_ptr, was_dirty, fail_val) \
+#define H5C__UPDATE_RP_FOR_MOVE(cache_ptr, entry_ptr, was_dirty, fail_val) \
{ \
HDassert( (cache_ptr) ); \
HDassert( (cache_ptr)->magic == H5C__H5C_T_MAGIC ); \
@@ -3012,7 +3012,7 @@ if ( ( (cache_ptr) == NULL ) || \
\
/* End modified LRU specific code. */ \
} \
-} /* H5C__UPDATE_RP_FOR_RENAME */
+} /* H5C__UPDATE_RP_FOR_MOVE */
#endif /* H5C_MAINTAIN_CLEAN_AND_DIRTY_LRU_LISTS */
@@ -637,19 +637,19 @@
* the current epoch.
*
- * renames: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1. The cells
+ * moves: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1. The cells
* are used to record the number of times an entry with type
@@ -637,19 +637,19 @@
* epoch.
*
- * entry_flush_renames: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1.
+ * entry_flush_moves: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1.
* The cells are used to record the number of times an entry
@@ -637,19 +637,19 @@
* during its flush callback in the current epoch.
*
- * cache_flush_renames: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1.
+ * cache_flush_moves: Array of int64 of length H5C__MAX_NUM_TYPE_IDS + 1.
* The cells are used to record the number of times an entry